searchData={"items":[{"type":"extras","title":"Zybo Z7-10","doc":"# Zybo Z7-10\n\n[![Hex version](https://img.shields.io/hexpm/v/nerves_system_zybo_z7_10.svg \"Hex version\")](https://hex.pm/packages/nerves_system_zybo_z7_10)\n\nThis is the base Nerves System configuration for the Zybo Z7-10.\n\n| Feature              | Description                                                 |\n| -------------------- | ----------------------------------------------------------- |\n| CPU                  | 667 MHz dual-core Cortex-A9 (ARMv7)                         |\n| Memory               | 1 GB DRAM                                                   |\n| Storage              | MicroSD                                                     |\n| Linux kernel         | 5.15                                                        |\n| IEx terminal         | HDMI and USB keyboard (can be changed to UART)              |\n| GPIO, I2C            | Yes - [Elixir Circuits](https://github.com/elixir-circuits) |\n| ADC                  | No, in this project's Bitstream                             |\n| PWM                  | No, in this project's Bitstream                             |\n| UART                 | 1 available - `ttyPS0`                                      |\n| Display              | HDMI                                                        |\n| Camera               | No, in this project's Bitstream                             |\n| Ethernet             | Yes                                                         |\n| WiFi                 | No                                                          |\n| Bluetooth            | No                                                          |\n| Audio                | Yes                                                         |","ref":"readme.html"},{"type":"extras","title":"Using - Zybo Z7-10","doc":"The most common way of using this Nerves System is create a project with `mix\nnerves.new` and to export `MIX_TARGET=zybo_z7_10`. See the [Getting started\nguide](https://hexdocs.pm/nerves/getting-started.html#creating-a-new-nerves-app)\nfor more information.\n\nIf you need custom modifications to this system for your device, clone this\nrepository and update as described in [Making custom\nsystems](https://hexdocs.pm/nerves/customizing-systems.html).","ref":"readme.html#using"},{"type":"extras","title":"Linux's preempt_rt patches - Zybo Z7-10","doc":"If you need better real-time performance from the Linux kernel, the `preempt_rt`\npatch set may help. Be aware that we do not test with the patches so this may\nnot work. To enable it, make a custom system using this one as a base and add\nthe following to the `nerves_defconfig`:\n\n```text\nBR2_LINUX_KERNEL_PATCH=\"http://cdn.kernel.org/pub/linux/kernel/projects/rt/4.19/patch-4.19.25-rt16.patch.xz\"\n```\n\nPlease verify the patch version since these instructions may be out-of-date.\n\nNext, update the Linux configuration to use it. Review the Nerves documentation\nfor running `make linux-menuconfig` and enable `PREEMPT_RT_FULL`. Alternately,\nmake the following change to the Linux configuration:\n\n```text\n-CONFIG_PREEMPT=y\n+CONFIG_PREEMPT_RT_FULL=y\n ```\n\nBuild the system and you should now have a preempt_rt kernel.","ref":"readme.html#linux-s-preempt_rt-patches"},{"type":"extras","title":"Provisioning devices - Zybo Z7-10","doc":"This system supports storing provisioning information in a small key-value store\noutside of any filesystem. Provisioning is an optional step and reasonable\ndefaults are provided if this is missing.\n\nProvisioning information can be queried using the Nerves.Runtime KV store's\n[`Nerves.Runtime.KV.get/1`](https://hexdocs.pm/nerves_runtime/Nerves.Runtime.KV.html#get/1)\nfunction.\n\nKeys used by this system are:\n\nKey                    | Example Value     | Description\n:--------------------- | :---------------- | :----------\n`nerves_serial_number` | `\"12345678\"`      | By default, this string is used to create unique hostnames and Erlang node names.\n\nThe normal procedure would be to set these keys once in manufacturing or before\ndeployment and then leave them alone.\n\nFor example, to provision a serial number on a running device, run the following\nand reboot:\n\n```elixir\niex> cmd(\"fw_setenv nerves_serial_number 12345678\")\n```\n\nThis system supports setting the serial number offline. To do this, set the\n`NERVES_SERIAL_NUMBER` environment variable when burning the firmware. If you're\nprogramming MicroSD cards using `fwup`, the commandline is:\n\n```sh\nsudo NERVES_SERIAL_NUMBER=12345678 fwup path_to_firmware.fw\n```\n\nSerial numbers are stored on the MicroSD card so if the MicroSD card is\nreplaced, the serial number will need to be reprogrammed. The numbers are stored\nin a U-boot environment block. This is a special region that is separate from\nthe application partition so reformatting the application partition will not\nlose the serial number or any other data stored in this block.\n\nAdditional key value pairs can be provisioned by overriding the default\nprovisioning.conf file location by setting the environment variable\n`NERVES_PROVISIONING=/path/to/provisioning.conf`. The default provisioning.conf\nwill set the `nerves_serial_number`, if you override the location to this file,\nyou will be responsible for setting this yourself.","ref":"readme.html#provisioning-devices"},{"type":"extras","title":"About board/system.bit, system.dtb, zynq_fsbl.elf - Zybo Z7-10","doc":"#","ref":"readme.html#about-board-system-bit-system-dtb-zynq_fsbl-elf"},{"type":"extras","title":"system.dtb - Zybo Z7-10","doc":"We use system.dtb which is generated by [Zybo-Z7-10-Petalinux-2022-1.bsp](https://github.com/Digilent/Zybo-Z7/releases/tag/10/Petalinux/2022.1-1/Zybo-Z7-10-Petalinux-2022-1.bsp).\n\n#","ref":"readme.html#system-dtb"},{"type":"extras","title":"system.bit and zynq_fsbl.elf - Zybo Z7-10","doc":"We regenerate Bitstream and FSBL by following steps to fix PS's GPIO\n\n```\n# refs. https://github.com/Digilent/digilent-vivado-scripts\ngit clone --recurse-submodules https://github.com/Digilent/Zybo-Z7.git\ncd Zybo-Z7/\ngit checkout 10/Petalinux/2022.1-1\ngit submodule update --init --recursive\n```\n\n1. Start Vivado 2023.2\n2. Click Tools -> Run Tcl Script...\n3. Select Zybo-Z7/hw/scripts/checkout.tcl and click OK\n4. **Fix MIO 50 and 51 pullup, from enable to disable**\n5. Generate Bitstream   \n   Critical warnings related to dvi2rgb occurs,  \n   but it only affects HDMI-in and has no effect on anything else, so we ignore them.\n6. Export XSA\n7. Create platform for the XSA\n8. Build FSBL\n\n \n\n#","ref":"readme.html#system-bit-and-zynq_fsbl-elf"},{"type":"extras","title":"Overwriting Files in the Boot Partition - Zybo Z7-10","doc":"see. [Nerves Advanced Configuration](https://hexdocs.pm/nerves/advanced-configuration.html#overwriting-files-in-the-boot-partition)","ref":"readme.html#overwriting-files-in-the-boot-partition"},{"type":"extras","title":"About UIO - Zybo Z7-10","doc":"- LD0-3  are binded with /dev/uio0\n- SW0-3  are binded with /dev/uio1's GPIO\n- BTN0-3 are binded with /dev/uio1's GPIO2\n- LD6     is binded with /dev/uio4\n\nsee. [UIOSAMPLE.md](UIOSAMPLE.md)","ref":"readme.html#about-uio"},{"type":"extras","title":"Loading Bitstream and dtbo at Linux runtime - Zybo Z7-10","doc":"1. upload Bitstream and dtbo to /tmp by sftp\n2. invoke following,\n\n```\niex> cmd \"cp /tmp/your_bitstream.bit.bit /lib/firmware\"\niex> cmd \"mkdir /configfs/device-tree/overlays/your_overlay\"\niex> cmd \"cat /tmp/your_overlay.dtbo > /configfs/device-tree/overlays/your_overlay/dtbo\"\n```","ref":"readme.html#loading-bitstream-and-dtbo-at-linux-runtime"},{"type":"extras","title":"UIOSAMPLE","doc":"#","ref":"uiosample.html"},{"type":"extras","title":"UIO Sample - UIOSAMPLE","doc":"Following is the normal c source code sample.  \nSo if you want to use UIO from Nerves, you need to write as NIF.\n\nsee also. https://www.kernel.org/doc/html/v5.15/driver-api/uio-howto.html\n\n```c\n#include  \n#include  \n#include  \n#include  \n#include  \n\n/* we can check this size by `cat /sys/class/uio/uioX/maps/map0/size` */\n#define SIZE 0x10000\n\n#define AXI_GPIO_LED \"/dev/uio0\"\n#define AXI_GPIO_SW_BTN \"/dev/uio1\"\n#define PWM_RGB \"/dev/uio4\"\n\n/* see. https://docs.xilinx.com/v/u/en-US/pg144-axi-gpio Register Space */\n#define GPIO_DATA_ADDR_OFFSET 0x0000\n#define GPIO_DATA2_ADDR_OFFSET 0x0008\n\n/* see. https://github.com/Digilent/libpwm/blob/master/libpwm.h */\n#define PWM_CTRL_OFFSET         0x0000\n#define PWM_PERIOD_OFFSET       0x0008\n#define PWM_DUTY_OFFSET         0x0040\n\nint main() {\n  int fd;\n  fd = open(AXI_GPIO_LED, O_RDWR);\n  if (fd < 0) {\n    return -1;\n  }\n\n  void *led_addr = mmap(NULL, SIZE, PROT_WRITE, MAP_SHARED_VALIDATE, fd, 0);\n  close(fd);\n\n  if (led_addr == MAP_FAILED) {\n    return -1;\n  }\n\n  fd = open(AXI_GPIO_SW_BTN, O_RDWR);\n  if (fd < 0) {\n    return -1;\n  }\n\n  void *sw_btn_addr = mmap(NULL, SIZE, PROT_READ, MAP_SHARED_VALIDATE, fd, 0);\n  close(fd);\n\n  if (sw_btn_addr == MAP_FAILED) {\n    return -1;\n  }\n\n  fd = open(PWM_RGB, O_RDWR);\n  if (fd < 0) {\n    return -1;\n  }\n\n  void *pwm_addr = mmap(NULL, SIZE, PROT_WRITE, MAP_SHARED_VALIDATE, fd, 0);\n  close(fd);\n\n  if (pwm_addr == MAP_FAILED) {\n    return -1;\n  }\n\n  uint32_t sw_bits = *(uint32_t *)(sw_btn_addr + GPIO_DATA_ADDR_OFFSET);\n  int sw0, sw1, sw2, sw3;\n  sw0 = (sw_bits & 0x01) >> 0;\n  sw1 = (sw_bits & 0x02) >> 1;\n  sw2 = (sw_bits & 0x04) >> 2;\n  sw3 = (sw_bits & 0x08) >> 3;\n\n  uint32_t btn_bits = *(uint32_t *)(sw_btn_addr + GPIO_DATA2_ADDR_OFFSET);\n  int btn0, btn1, btn2, btn3;\n  btn0 = (btn_bits & 0x01) >> 0;\n  btn1 = (btn_bits & 0x02) >> 1;\n  btn2 = (btn_bits & 0x04) >> 2;\n  btn3 = (btn_bits & 0x08) >> 3;\n\n  printf(\"sw = %d%d%d%d\\n\", sw3, sw2, sw1, sw0);\n  printf(\"btn = %d%d%d%d\\n\", btn3, btn2, btn1, btn0);\n\n  *(uint32_t *)(led_addr + GPIO_DATA_ADDR_OFFSET) = sw_bits | btn_bits;\n\n  *(uint32_t *)(pwm_addr + PWM_CTRL_OFFSET)   = sw3;\n  *(uint32_t *)(pwm_addr + PWM_PERIOD_OFFSET) = 10;\n  *(uint32_t *)(pwm_addr + PWM_DUTY_OFFSET   + (4 * 2)) = sw2;\n  *(uint32_t *)(pwm_addr + PWM_DUTY_OFFSET   + (4 * 1)) = sw1;\n  *(uint32_t *)(pwm_addr + PWM_DUTY_OFFSET   + (4 * 0)) = sw0;\n\n  munmap(sw_btn_addr, SIZE);\n  munmap(led_addr, SIZE);\n  return 0;\n}\n```","ref":"uiosample.html#uio-sample"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nThis project does NOT follow semantic versioning. The version increases as\nfollows:\n\n1. Major version updates are breaking updates to the build infrastructure.\n   These should be very rare.\n2. Minor version updates are made for every major Buildroot release. This\n   may also include Erlang/OTP and Linux kernel updates. These are made four\n   times a year shortly after the Buildroot releases.\n3. Patch version updates are made for Buildroot minor releases, Erlang/OTP\n   releases, and Linux kernel updates. They're also made to fix bugs and add\n   features to the build infrastructure.","ref":"changelog.html"},{"type":"extras","title":"v0.0.2 - Changelog","doc":"This is a major Buildroot and toolchain update.\n\n* Updated dependencies\n  * [nerves_system_br v1.25.2](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.25.2)\n  * [Erlang/OTP 26.1.2](https://erlang.org/download/OTP-26.1.2.README)\n  * [Buildroot 2023.08.4](https://lore.kernel.org/buildroot/87o7f6t7fs.fsf@48ers.dk/T/)","ref":"changelog.html#v0-0-2"},{"type":"extras","title":"v0.0.1 - Changelog","doc":"* Dependencies\n  * [nerves_system_br v1.24.1](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.24.1)\n  * [Erlang/OTP 26.1.1](https://erlang.org/download/OTP-26.1.1.README)\n  * [Buildroot 2023.05.3](https://lore.kernel.org/buildroot/87h6ngup34.fsf@48ers.dk/T/)\n\n#","ref":"changelog.html#v0-0-1"},{"type":"extras","title":"This system uses followings, - Changelog","doc":"* https://github.com/Digilent/linux-digilent 's digilent_rebase_v5.15_LTS_2022.1 branch for Linux kernel.\n* https://github.com/Digilent/u-boot-digilent 's digilent_rebase_v2022.01 branch for U-boot.\n\nTo pin the sources, we download the tarballs from a specific commit on the branch.","ref":"changelog.html#this-system-uses-followings"}],"content_type":"text/markdown"}